;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "evil-collection" "20251024.2337"
  "A set of keybindings for Evil mode."
  '((emacs    "26.3")
    (evil     "1.2.13")
    (annalist "1.0"))
  :url "https://github.com/emacs-evil/evil-collection"
  :commit "092408dcf7655c299d69b8cacb85bdea59598196"
  :revdesc "092408dcf765"
  :keywords '("evil" "tools")
  :authors '(("James Nguyen" . "james@jojojames.com"))
  :maintainers '(("James Nguyen" . "james@jojojames.com")))
